{
    package GCLang::TR;

    use utf8;
###################################################
#
#  Copyright 2005-2006 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
#
# Turkish Language File, v.2
# KaraGarga, 17/07/2006
# 
###################################################   

    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Türkçe',
        
        'Separator' => ': ',
        
        'Warning' => '<b>Dikkat!</b>:
        
Eklentiler aracılığıyla diğer sitelerden indirilen bilgiler 
sadece <b>kişisel amaçlar için</b> kullanılmalıdır.

Bu bilgilerin, ilgili sitenin izni olmaksızın dağıtımı
<b>yasaktır</b>.

Bilginin hangi siteden alındığını <b>film detaylarının altındaki link düğmesinden öğrenebilirsiniz.</b>.',
        
        'AllItemsFiltered' => 'Aradığınız anahtar sözcükle ilişkili bir film bulunamadı.',
        
#Installation
        'InstallDirInfo' => 'Kurulum klasörü ',
        'InstallMandatory' => 'Gerekli Bileşenler',
        'InstallOptional' => 'Diğer Bileşenler',
        'InstallErrorMissing' => 'Hata : Aşağıdaki Perl bileşenini kurmalısınız: ',
        'InstallPrompt' => 'Yazılımın kurulacağı klasör [/usr/local]: ',
        'InstallEnd' => 'Kurulumun sonu',
        'InstallNoError' => 'Hata Yok',
        'InstallLaunch' => 'Bu yazılımı kullanmak için, şunu başlatmalısınız ',
        'InstallDirectory' => 'Ana klasör',
        'InstallTitle' => 'GCstar kurulumu',
        'InstallDependencies' => 'Bağımlı bileşenler',
        'InstallPath' => 'Dizin',
        'InstallOptions' => 'Seçenekler',
        'InstallSelectDirectory' => 'Kurulum için bir ana klasör seçiniz',
        'InstallWithClean' => 'Kurulum dizinindeki dosyaları temizle',
        'InstallWithMenu' => 'GCstar yazılımını Programlar menüsüne ekle',
        'InstallNoPermission' => 'Hata: Seçtiğiniz klasöre yazma hakkınız yok',
        'InstallMissingMandatory' => 'Zorunlu bileşenler eksik. Bu bileşenleri kurmadan GCstar yazılımını kullanamazsınız.',
        'InstallMissingOptional' => 'Bazı seçimlik bileşenler eksik. Bu bileşenler aşağıda listelenmiştir. GCstar yazılımını kurabilirsiniz ancak bu bileşenler olmadan bazı özelliklerini kullanmayabilirsiniz.',
        'InstallMissingNone' => 'Eksik bağımlı bileşen yok. GCstar yazılımını kurmaya devam edebilirsiniz.',
        'InstallOK' => 'Tamam',
        'InstallMissing' => 'Eksik',
        'InstallMissingFor' => 'Eksikler',
        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
        'InstallCopyDirectory' => 'Copying files in directory: ',
        'InstallCopyDesktop' => 'Copying desktop file in: ',

#Update
        'UpdateUseProxy' => 'Kullanılacak Proxy (emin değilseniz sadece entere basınız): ',
        'UpdateNoPermission' => 'Bu klasöre yazma hakkınız yok ya da reddedildi: ',
        'UpdateNone' => 'Herhangi bir güncelleme bulunamadı.',
        'UpdateFileNotFound' => 'Dosya bulunamadı',

#Splash
    	'SplashInit' => 'Program açılıyor...',
    	'SplashLoad' => 'Veritabanı yükleniyor...',
        'SplashDisplay' => 'Displaying Collection',
    	'SplashDone' => 'Hazır.',

#Import from GCfilms
        'GCfilmsImportQuestion' => 'Daha önce GCfilms yazılımını kullanıyordunuz. Bu yazılımdaki verileri otomatik almak ister misiniz? (bu seçenk GCfilms yazılımını kullanmanızı etkilemeyecektir.)',
        'GCfilmsImportOptions' => 'Ayarlar',
        'GCfilmsImportData' => 'Film Listesi',

#Menus
        'MenuFile' => '_Dosya',
            'MenuNewList' => '_Yeni Kolleksiyon',
            'MenuHistory' => '_Son Kullanılanlar',
            'MenuLend' => 'Ö_dünç Verilenler',
            'MenuImport' => '_Al',	
            'MenuExport' => '_Ver',
    
        'MenuEdit'  => 'Düz_enle',
            'MenuDuplicate' => '_Kopyasını oluştur',
            'MenuEditDeleteCurrent' => '_Sil',
            'MenuEditFields' => '_Change collection fields',
            'MenuEditLockItems' => '_Veritabanını kilitle',
    
        'MenuDisplay' => '_Filtrele',
            'MenuAdvancedSearch' => 'A_dvanced Search',
            'MenuViewAllItems' => 'Tümünü Göste',
            'MenuNoFilter' => '_Hepsi',
    
        'MenuConfiguration' => '_Ayarlar',
            'MenuDisplayOptions' => '_Bilgi Alanları',
            'MenuBorrowers' => '_Ödünç Alanlar',
            'MenuGenresConversion' => '_Tür Çevrimi',
        
        'MenuBookmarks' => 'My _Collections',
            'MenuBookmarksAdd' => '_Add current collection',
            'MenuBookmarksEdit' => '_Edit bookmarked collections',

        'MenuHelp' => '_Yardım',
            'MenuHelpContent' => '_Yardım',
            'MenuAllPlugins' => 'View _plugins',
            'MenuBugReport' => 'Report a _bug',
            'MenuAbout' => 'GCstar _Hakkında',
    
        'MenuNewWindow' => '_Yeni Pencerede Göster',
        
        'ContextExpandAll' => 'Hepsini Aç',
        'ContextCollapseAll' => 'Hepsini Kapa',
        
        'DialogEnterNumber' => 'Lütfen bir değer giriniz',

        'RemoveConfirm' => 'Bu başlığı silmek istediğinize emin misiniz?',
        'DefaultNewItem' => 'New item',
        'NewItemTooltip' => 'Yeni başlık eklemek için tıklayın',
        'NoItemFound' => 'Aradığınız başlık bulunamadı. Başka bir siteden arama yapmak ister misiniz?',
        'OpenList' => 'Lütfen bir veritabanı seçin',
        'SaveList' => 'Listeyi nereye kaydedeceğiniz seçiniz',
        'SaveListTooltip' => 'Açık olan veritabanını kaydetmek için tıklayınız',
        'SaveCurrentList' => 'Listeyi nereye kaydedeceğiniz seçiniz',
        'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
        'SaveDontSave' => 'Don\'t save',
        'PreferencesTooltip' => 'Ayarları yapmak için tıklayınız',
        'ViewTooltip' => 'Koleksiyonun görsel ayarlarını değiştirir',
        'PlayTooltip' => 'Dosyayı lişkilendirilmiş oynatıcı ile başlatır',

        'StatusSave' => 'Saving...',
        'StatusLoad' => 'Loading...',
        'StatusSearch' => 'Aranıyor...',
        'StatusGetInfo' => 'Bilgiler alınıyor...',
        'StatusGetImage' => 'Kapak alınıyor...',
                
        'SaveError' => 'GCStar Koleksiyonu kaydedilemiyor. Erişim engelleri ve boş alan kontrolü yapınız.',
        'OpenError' => 'GCStar Koleksiyonu açamıyor. Dosyanın erişim izinlerini kontrol ediniz.',
		'OpenFormatError' => 'Koleksiyonu açamıyor.',
        'ImageError' => 'Kapak dosyaları için seçtiğiniz klasör yanlış. Lütfen başka bir klasör seçiniz.',
        'OptionsCreationError'=> 'Ayar dosyası oluşturulamıyor: ',
        'OptionsOpenError'=> 'Ayar dosyası açılamıyor: ',
        'OptionsSaveError'=> 'Ayar dosyası kaydedilemiyor: ',
        
        'RandomTooltip' => 'Bana öneride bulun. Rastgele dosya seçer.',
        'RandomError'=> 'Tüm başlıkları izlemişsiniz ya da veritanında başlık yok.',
        'RandomEnd'=> 'Tüm başlıkları izlemişsiniz. Başka başlık kalmadı.',
        'RandomNextTip'=> 'Bir Sonraki Öneri',
        'RandomOkTip'=> 'Tamam bu iyi',
        
        'AboutTitle' => 'GCstar Hakkında',
        'AboutDesc' => 'Veritabanı Yöneticisi',
        'AboutVersion' => 'Sürüm',
        'AboutTeam' => 'Takım',
        'AboutWho' => 'Tian: Proje Yöneticisi, Programcı
Adolfo González : Programcı',
        'AboutLicense' => 'GNU GPL lisansı altında dağıtılmaktadır
Logoların telif hakları le Spektre
http://le-spektre.org\'a aittir.',
        'AboutTranslation' => 'Türkçe çeviri KaraGarga\'ya aittir',
        'AboutDesign' => 'Logo ve webtasarımı: le Spektre',

        'ToolbarRandom' => 'Gece',

        'ModelsSelect' => 'Bir koleksiyon türü seçiniz',
        'ModelsPersonal' => 'Personal models',
        'ModelsDefault' => 'Default models',
        'ModelsList' => 'Koleksiyon Türleri',
        'ModelSettings' => 'Collection settings',
        'ModelNewType' => 'New collection type',
        'ModelName' => 'Name of the collection type:',
        'ModelNewField' => 'New field',
        'ModelFieldInformation' => 'Information',
        'ModelFieldName' => 'Label:',
        'ModelFieldType' => 'Type:',
        'ModelFieldGroup' => 'Group:',
        'ModelFieldValues' => 'Values',
        'ModelFieldInit' => 'Default:',
        'ModelFieldMin' => 'Minimum:',
        'ModelFieldMax' => 'Maximum:',
        'ModelFieldList' => 'Values list:',
        'ModelFieldListLegend' => '<i>Comma separated</i>',
        'ModelFieldTypeShortText' => 'Short text',
        'ModelFieldTypeLongText' => 'Long text',
        'ModelFieldTypeYesNo' => 'Yes/No',
        'ModelFieldTypeNumber' => 'Number',
        'ModelFieldTypeDate' => 'Date',
        'ModelFieldTypeOptions' => 'Pre-defined values list',
        'ModelFieldTypeImage' => 'Image',
        'ModelFieldTypeSingleList' => 'Simple list',
        'ModelFieldTypeFile' => 'File',
        'ModelFieldParameters' => 'Parameters',
        'ModelFieldHasHistory' => 'Use an history',
        'ModelFieldFlat' => 'Display on one line',
        'ModelFieldStep' => 'Increment step:',
        'ModelFieldFileFormat' => 'File format:',
        'ModelFieldFileFile' => 'Simple file',
        'ModelFieldFileImage' => 'Image',
        'ModelFieldFileVideo' => 'Video',
        'ModelFieldFileAudio' => 'Audio',
        'ModelFieldFileProgram' => 'Program',
        'ModelFieldFileUrl' => 'URL',
        'ModelOptionsFields' => 'Fields to use',
        'ModelOptionsFieldsAuto' => 'Automatic',
        'ModelOptionsFieldsNone' => 'None',
        'ModelOptionsFieldsTitle' => 'As title',
        'ModelOptionsFieldsId' => 'As identifier',
        'ModelOptionsFieldsCover' => 'As cover',
        'ModelOptionsFieldsPlay' => 'For Play button',
        'ModelCollectionSettings' => 'Collection settings',
        'ModelCollectionSettingsLending' => 'Items could be borrowed',
        'ModelFilterActivated' => 'Should be in search box',
        'ModelFilterComparison' => 'Comparison',
        'ModelFilterContain' => 'Contains',
        'ModelFilterRange' => 'Range',
        'ModelFilterNumeric' => 'Comparison is numeric',
        'ModelFilterQuick' => 'Create a quick filter',
        'ModelTooltipName' => 'Use a name to re-use this model for many collections. If empty, the settings will be directly stored in the collection itself',
        'ModelTooltipLabel' => 'The field name as it will be displayed',
        'ModelTooltipGroup' => 'Used to group fields. Items with no value here will be in a default group',
        'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
        'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
        'ModelTooltipLending' => 'This will add some fields to manage lendings',
        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
        'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
        
        'ResultsTitle' => 'Bir başlık seçiniz',
        'ResultsNextTip' => 'Bir sonraki sitede ara',
        'ResultsPreview' => 'Preview',
        
        'OptionsTitle' => 'Ayarlar',
        'OptionsBrowser' => 'Web tarayıcı',
        'OptionsPlayer' => 'Video oynatıcı',
        'OptionsAudio' => 'Audio oynatıcı',
        'OptionsImages' => 'Kapak klasörü',
        'OptionsUseRelativePaths' => 'Kapak resimleri için değişken dizin yapısı kullan',
        'OptionsLayout' => 'Başlık Bilgileri Paneli',
        'OptionsStatus' => 'Durum barını göster',
        'OptionsWarning' => 'Dikkat: Bu alandaki değişikleri uygulamak için yazılımı tekrar başlatmalısınız.',
        'OptionsRemoveConfirm' => 'Başlık silmeden önce onay iste',
        'OptionsAutoSave' => 'Veritabanını otomatik olarak kaydet',
        'OptionsAutoLoad' => 'Load previous collection on startup',
        'OptionsSplash' => 'Başlangıç ekranını göster',
        'OptionsImagesTitle' => 'Bir Klasör Seçiniz',
        'OptionsProgramTitle' => 'Bir Program Seçiniz',
		'OptionsPlugins' => 'Bilginin alınacağı siteyi seçiniz',
		'OptionsAskPlugins' => 'Sor (Tüm Siteler)',
		'OptionsPluginsMulti' => 'Seçtiğim Siteler',
		'OptionsPluginsMultiAsk' => 'Sor (Seçtiğim Siteler)',
		'OptionsPluginsList' => 'Listeyi oluşturun',
        'OptionsAskImport' => 'Alınacak bilgi alanları',
		'OptionsProxy' => 'Proxy Kullan',
        'OptionsLang' => 'Dil',
        'OptionsMain' => 'Genel',
        'OptionsPaths' => 'Dizin',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' => 'Diğer',
        'OptionsDisplay' => 'Görsel',
        'OptionsToolbar' => 'Menü',
        'OptionsToolbars' => {0 => 'Yok', 1 => 'Küçük', 2 => 'Büyük'},
        'OptionsToolbarPosition' => 'Konum',
        'OptionsToolbarPositions' => {0 => 'Üst', 1 => 'Alt', 2 => 'Sol', 3 => 'Sağ'},
        'OptionsView' => 'Film Listesi',
        'OptionsViews' => {0 => 'Başlık Adları', 1 => 'Kapak', 2 => 'Detay'},
        'OptionsColumns' => 'Kolonlar',
        'OptionsMailer' => 'E-posta istemcisi',
        'OptionsSMTP' => 'Sunucu',
        'OptionsFrom' => 'E-posta adresiniz',
        'OptionsTransform' => 'Aşağıdaki öbekleri film adının sonuna koy',
        'OptionsArticles' => 'Öbekler (virgülle ayrılmış)',
        'OptionsSearchStop' => 'Aramanın durdurulmasını sağlar',
        'OptionsAlwaysOriginal' => 'Başlık için özgün ad yoksa kendi adını kullan',
        'OptionsHistory' => 'Geçmiş dosya kısıtlaması',
        'OptionsClearHistory' => 'Geçmişi temizle',
		'OptionsStyle' => 'Arayüz',
        'OptionsDontAsk' => 'Bir daha sorma',
        'OptionsPathProgramsGroup' => 'Yazılımlar',
        'OptionsPathImagesGroup' => 'Resimler',
        'OptionsInternetDataGroup' => 'Veri alma',
        'OptionsInternetSettingsGroup' => 'Ayarlar',
        'OptionsDisplayInformationGroup' => 'Bilgi gösterimi',
        'OptionsDisplayArticlesGroup' => 'Articles',
        'OptionsImagesDisplayGroup' => 'Görsel',
        'OptionsImagesStyleGroup' => 'Stil',
        'OptionsDetailedPreferencesGroup' => 'Seçenekler',
        'OptionsFeaturesConveniencesGroup' => 'Conveniences',
        'OptionsPicturesFormat' => 'Prefix to use for pictures:',
        'OptionsPicturesFormatInternal' => 'gcstar__',
        'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
        'OptionsConfigureMailers' => 'Configure mailing programs',

        'ImagesOptionsButton' => 'Ayarlar',
        'ImagesOptionsTitle' => 'Kağak listesi için ayarlar',
        'ImagesOptionsSelectColor' => 'Renk seçiniz',
        'ImagesOptionsBg' => 'Arkaplan',
        'ImagesOptionsBgPicture' => 'Arkaplan resmi kullan',
        'ImagesOptionsFg'=> 'Seçim',
        'ImagesOptionsBgTooltip' => 'Arkaplanı değiştir',
        'ImagesOptionsFgTooltip'=> 'Seçili alan rengini değiştir',
        'ImagesOptionsSizeLabel' => 'Boyut',
        'ImagesOptionsSizeList' => {0 => 'Minik', 1 => 'Küçük', 2 => 'Orta', 3 => 'Büyük', 4 => 'Devasa'},
        'ImagesOptionsSizeTooltip' => 'Resim boyutu seçiniz',
		        
        'DetailedOptionsTitle' => 'Detaylı liste için ayarlar',
        'DetailedOptionsImageSize' => 'Kapak boyutu',
        'DetailedOptionsGroupItems' => 'Filmleri Koleksiyon türüne göre sınıflandır',
		'DetailedOptionsFields' => 'Gösterilecek alanları seçiniz',
		'DetailedOptionsMasterOption' => 'Group master is',
		'DetailedOptionsMasterGenerated' => 'Auto generated',
		'DetailedOptionsMasterOrdered' => 'Determined by',

        'ExtractButton' => 'Bilgi',
        'ExtractTitle' => 'Video Bilgisi',
        'ExtractImport' => 'Bu değerleri kullan',

        'FieldsListOpen' => 'Load a fields list from a file',
        'FieldsListSave' => 'Save fields list to a file',
        'FieldsListError' => 'This fields list cannot be used with this kind of collection',

        'ExportTitle' => 'Film listesini ver',
        'ExportFilter' => 'Sadece seçili filmleri ver',
        'ExportFieldsTitle' => 'Verilecek alanlar',
        'ExportFieldsTip' => 'Aktarılacak alanları seçiniz',
        'ExportWithPictures' => 'Kapak resimlerini bir alt klasöre kopyala',

        'ImportListTitle' => 'Diğer bir film listesinden aktar',
        'ImportExportData' => 'Data',
        'ImportExportFile' => 'Dosya',
        'ImportExportSave' => 'Lütfen bir dosya seçiniz',
        'ImportExportFieldsUnused' => 'Kullanılmayacak alanlar',
        'ImportExportFieldsUsed' => 'Kullanılacak alanlar',
        'ImportExportFieldsFill' => 'Tümüün Ekle',
        'ImportExportFieldsClear' => 'Tümünü Sil',
        'ImportExportFieldsEmpty' => 'En az bir alan seçmelisiniz',
        'ImportExportFileEmpty' => 'Dosya adı belirlemelisiniz',
        'ImportFieldsTitle' => 'Alınacak Alanlar',
        'ImportFieldsTip' => 'Alınacak alanları seçiniz',
        'ImportNewList' => 'Yeni veritabanı oluştur',
        'ImportCurrentList' => 'Açık olan veritabanına aktar',
        'ImportDropError' => 'Dosyanın açılmasında sorun çıktı. Bir önceki veritabanı yüklenecek.',

        'FileOverwrite' => 'Bu dosya zaten var. Üzerine yazmak istediğinizden emin misiniz?',

        #Some default panels
        'PanelCompact' => 'İşlevsel',
        'PanelReadOnly' => 'Salt Okunur',
        'PanelForm' => 'Sekmeler',

        'PanelSearchButton' => 'Bilgi Al',
        'PanelSearchTip' => 'Bu film için internetten bilgi al',
        'PanelImageTipOpen' => 'Başka bir kapak resmi seçmek için tıklayınız.',
        'PanelImageTipView' => 'Click on the picture to view it in real size.',
        'PanelImageTipMenu' => ' Daha fazla seçenek için sağ tıklayınız.',
        'PanelImageTitle' => 'Kapak seç',
        'PanelImageNoImage' => 'No image',
        'PanelSelectFileTitle' => 'Dosya Seçiniz',

        'PanelFrom' =>'From',
        'PanelTo' =>'To',

        'PanelWeb' => 'Bilgileri göster',
        'PanelWebTip' => 'Bu filmin internet bilgisini göster',
        'PanelRemoveTip' => 'Seçili filmi siliniz',

        'PanelDateSelect' => 'Tarih Seçiniz',
        'PanelNobody' => 'Kimse',
        'PanelUnknown' => 'Bilinmiyor',

        'PanelLending' => 'Ödünç',
        'PanelBorrower' => 'Ödünç Alan',
        'PanelLendDate' => 'Ödünç Verme Tarihi',
        'PanelHistory' => 'Ödünç Geçmişi',
        'PanelReturned' => 'Geri Dönme Tarihi',
        'PanelReturnDate' => 'Geri dönme tarihi',
        'PanelLendedYes' => 'Ödün verilme',
        'PanelLendedNo' => 'Arşivde',

        'CheckUndef' => 'Farketmez',
        'CheckYes' => 'Evet',
        'CheckNo' => 'Hayır',

        'ToolbarAll' => 'Tümünü Göster',
        'ToolbarAllTooltip' => 'Tüm filmleri görmek için tıklayınız',
        'ToolbarGroupBy' => 'Grupla',
        'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
        
        'PluginsTitle' => 'Film arayınız',
        'PluginsQuery' => 'Query',
        'PluginsFrame' => 'Arama sitesi',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Adı',
        'PluginsSearchFields' => 'Search fields',
        'PluginsAuthor' => 'Yazarı',
        'PluginsLang' => 'Dil',
        'PluginsUseSite' => 'Her zaman bu siteyi kullan',

        'BorrowersTitle' => 'Ödünç Seçenekleri',
        'BorrowersList' => 'Borrowers',
        'BorrowersName' => 'Adı',
        'BorrowersEmail' => 'E-posta',
        'BorrowersAdd' => 'Ekle',
        'BorrowersRemove' => 'Sil',
        'BorrowersEdit' => 'Düzenle',
        'BorrowersTemplate' => 'E-posta örneği',
        'BorrowersSubject' => 'Posta konusu',
        'BorrowersNotice1' => '%1 - Ödünç alanın adı',
        'BorrowersNotice2' => '%2 - Film adı',
        'BorrowersNotice3' => '%3  - Ödün alma tarihi',

        'BorrowersImportTitle' => 'Import borrowers information',
        'BorrowersImportType' => 'File format:',
        'BorrowersImportFile' => 'File:',

        'BorrowedTitle' => 'Ödünç verilmiş filmler',
        'BorrowedDate' => 'Alma Tarihi',

        'MailTitle' => 'E-posta gönder',
        'MailFrom' => 'Kimden: ',
        'MailTo' => 'Kime: ',
        'MailSubject' => 'Konu: ',
        'MailSmtpError' => 'SMTP sunucusuna bağlanamıyor',
        'MailSendmailError' => 'Sendmail istemcisini çalıştıramıyor',

        'SearchTooltip' => 'Detaylı arama için tıklayınız',
        'SearchTitle' => 'Film Arama',

        'QueryReplaceField' => 'Değiştirilecek alan',
        'QueryReplaceOld' => 'Şimdiki değer',
        'QueryReplaceNew' => 'Yeni Değer',
        'QueryReplaceLaunch' => 'Değiştir',
        
        'ImportWindowTitle' => 'Alınacak alanları seçiniz',
        'ImportViewPicture' => 'Resmi göster',
        'ImportSelectAll' => 'Tümünü seç',
        'ImportSelectNone' => 'Hiçbirini seçme',

        'MultiSiteTitle' => 'Arama için kullanılan siteler',
        'MultiSiteUnused' => 'Kullanılmayacaklar',
        'MultiSiteUsed' => 'Kullanılacak eklentiler',
        'MultiSiteLang' => 'İngilizce eklentileri göster',
        'MultiSiteEmptyError' => 'Site listeniz boş',
        'MultiSiteClear' => 'Listeyi temizle',
        
        'DisplayOptionsTitle' => 'Gösterilecek alanlar',
        'DisplayOptionsAll' => 'Tümünü Seç',
        'DisplayOptionsSearch' => 'Arama düğmesi',

        'GenresTitle' => 'Tür Dönüştürme',
        'GenresCategoryName' => 'Kullanılan Tür',
        'GenresCategoryMembers' => 'Değiştirilecek Tür',
        'GenresLoad' => 'Liste yükle',
        'GenresExport' => 'Listeyi kaydet',
        'GenresModify' => 'Tür Düzenle',

        'PropertiesName' => 'Collection name',
        'PropertiesOwner' => 'Owner',
        'PropertiesEmail' => 'Email',
        'PropertiesDescription' => 'Description',
        'PropertiesFile' => 'File Information',
        'PropertiesFilePath' => 'Full path',
        'PropertiesItemsNumber' => 'Number of items',
        'PropertiesFileSize' => 'Size',
        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
        'PropertiesCollection' => 'Collection properties',

        'MailProgramsTitle' => 'Programs for mail sending',
        'MailProgramsName' => 'Name',
        'MailProgramsCommand' => 'Command line',
        'MailProgramsRestore' => 'Restore defaults',
        'MailProgramsAdd' => 'Add a program',
        'MailProgramsInstructions' => 'In command line, some substitutions are made:
 %f is replaced with user\'s e-mail address.
 %t is replaced with the recipient address.
 %s is replaced with the subject of the message.
 %b is replaced with the body of the message.',

        'BookmarksBookmarks' => 'Bookmarks',
        'BookmarksFolder' => 'Directory',
        'BookmarksLabel' => 'Label',
        'BookmarksPath' => 'Path',
        'BookmarksNewFolder' => 'New folder',

        'AdvancedSearchType' => 'Type of search',
        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
        'AdvancedSearchCriteria' => 'Criteria',
    );
}
1;
